@@ -1,11 +1,11 @@
 from pathlib import Path
 
-VERSION = '0.0.32'
+VERSION = '0.0.35'
 CLI_NAME = 'figgy'
 PROJECT_NAME = 'figgy'
 
 # Figgy URLS
-FIGGY_GITHUB = "https://github.com/mancej/figgy"
+FIGGY_GITHUB = "https://github.com/figtools/figgy"
 FIGGY_OBS_API_BASE_URL = "https://api.figgy.dev"
 
 # Paths
@@ -13,6 +13,9 @@ FIGGY_ERROR_REPORTING_URL = f"{FIGGY_OBS_API_BASE_URL}/v1/log-error"
 FIGGY_GET_VERSION_URL = f"{FIGGY_OBS_API_BASE_URL}/v1/version"
 FIGGY_LOG_METRICS_URL = f"{FIGGY_OBS_API_BASE_URL}/v1/log-metrics"
 
+# Homebrew
+BREW_FORMULA = 'figtools/figgy/figgy'
+
 # Role names are assumed to be prefixed with `figgy-` - Users may override by setting the below ENV variable.
 FIGGY_ROLE_NAME_PREFIX = 'figgy-'
 FIGGY_ROLE_PREFIX_OVERRIDE_ENV = 'FIGGY_ROLE_PREFIX_OVERRIDE'
@@ -147,4 +150,7 @@ KEYCHAIN_ENCRYPTION_KEY = 'figgy-encryption-key'
 
 # This is only used for temporary sandbox sessions. This reduces user friction when experimenting by not having to interact
 # with authenticating their OS Keychain.
-DEFAULT_ENCRYPTION_KEY = 'wX1C0nK1glfzaWQU8SKukdS7XZgYlAMW5ueb_V3cfSE='
\ No newline at end of file
+DEFAULT_ENCRYPTION_KEY = 'wX1C0nK1glfzaWQU8SKukdS7XZgYlAMW5ueb_V3cfSE='
+
+# Default paths to search for figgy.json in
+DEFAULT_FIGGY_JSON_PATHS = ['figgy.json', 'figgy/figgy.json', 'config/figgy.json', '_figgy/figgy.json', '.figgy/figgy.json']
\ No newline at end of file
